pub struct EmergencyControl { /* private fields */ }Expand description
Emergency control interface
Provides emergency stop functionality that immediately stops all motors.
Implementations
Sourceimpl EmergencyControl
impl EmergencyControl
Sourcepub async fn send_emergency_stop(&self) -> Result<()>
👎Deprecated since 0.8.1: Use Supervisor::send_emergency_stop instead
pub async fn send_emergency_stop(&self) -> Result<()>
Use Supervisor::send_emergency_stop instead
Send emergency stop command
Immediately stops all motors and puts the Crazyflie into a locked state. The drone will require a reboot before it can fly again.
Sourcepub async fn send_emergency_stop_watchdog(&self) -> Result<()>
👎Deprecated since 0.8.1: Use Supervisor::send_emergency_stop_watchdog instead
pub async fn send_emergency_stop_watchdog(&self) -> Result<()>
Use Supervisor::send_emergency_stop_watchdog instead
Send emergency stop watchdog
Activates/resets a watchdog failsafe that will automatically emergency stop the drone if this message isn’t sent every 1000ms. Once activated by the first call, you must continue sending this periodically forever or the drone will automatically emergency stop. Use only if you need automatic failsafe behavior.